aboutsummaryrefslogtreecommitdiffstats
path: root/sm/export.c
diff options
context:
space:
mode:
authorDaniel Kahn Gillmor <[email protected]>2024-05-12 22:09:23 +0000
committerWerner Koch <[email protected]>2024-05-31 10:28:32 +0000
commit42b0e9558a308dbc954ee60c3d346b5cabcd2fdb (patch)
treef073776758cd706a0cadf0bd64073d1669a8d691 /sm/export.c
parentg13: Adjust for changed gnupg_process_spawn. (diff)
downloadgnupg-42b0e9558a308dbc954ee60c3d346b5cabcd2fdb.tar.gz
gnupg-42b0e9558a308dbc954ee60c3d346b5cabcd2fdb.zip
indent: Fix spelling
-- These are non-substantive corrections for minor spelling mistakes within the GnuPG codebase. With something like this applied to the codebase, and a judiciously tuned spellchecker integrated as part of a standard test suite, it should be possible to keep a uniform orthography within the project. GnuPG-bug-id: 7116
Diffstat (limited to 'sm/export.c')
-rw-r--r--sm/export.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sm/export.c b/sm/export.c
index a6ba40f5d..7b188c2fe 100644
--- a/sm/export.c
+++ b/sm/export.c
@@ -318,7 +318,7 @@ gpgsm_export (ctrl_t ctrl, strlist_t names, estream_t stream)
/* Export a certificate and its private key. RAWMODE controls the
actual output:
- 0 - Private key and certifciate in PKCS#12 format
+ 0 - Private key and certificate in PKCS#12 format
1 - Only unencrypted private key in PKCS#8 format
2 - Only unencrypted private key in PKCS#1 format
*/
@@ -485,7 +485,7 @@ gpgsm_p12_export (ctrl_t ctrl, const char *name, estream_t stream, int rawmode)
}
/* Print some info about the certifciate CERT to FP or STREAM */
static void
print_short_info (ksba_cert_t cert, estream_t stream)
{
@@ -485,7 +485,7 @@ gpgsm_p12_export (ctrl_t ctrl, const char *name, estream_t stream, int rawmode)
}
-/* Print some info about the certifciate CERT to FP or STREAM */
+/* Print some info about the certificate CERT to FP or STREAM */
static void
print_short_info (ksba_cert_t cert, estream_t stream)